#
# spec file for package pgadmin3
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           pgadmin3
Version:        1.22.2
Release:        50.6
Summary:        Management and Administration Tools for the PostgreSQL Database
License:        PostgreSQL
Group:          Productivity/Databases/Tools
Url:            http://www.pgadmin.org/index.php
Source0:        https://ftp.postgresql.org/pub/pgadmin/%{name}/v%{version}/src/pgadmin3-%{version}.tar.gz
Source1:        %name.desktop
Source2:        %name.png
Source4:        https://ftp.postgresql.org/pub/pgadmin/%{name}/v%{version}/src/pgadmin3-%{version}.tar.gz.sig
# Limit to strict minimum the needed wxWidgets inspired by debian patches
Patch0:         wxWidget-limit-libs-used.patch
# Fix row heights on hidpi screen
Patch1:         0001-Set-row-heights-based-on-pixels-rather-than-points.patch
# Add basic support for postgresql10 (Based on pgadmin3 lts by bigsql
# https://bitbucket.org/openscg/pgadmin3-lts/commits/ea8a31af779b101248fc13242cb7a34e252cf49e
# https://bitbucket.org/openscg/pgadmin3-lts/commits/1d65e012f7bb88d3b6c5a08946a2456617213c35
Patch2:         0002-basic-support-postgresql10.patch
Patch3:         0003-postgresql-8.3-support.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
%if 0%{?is_opensuse} > 0
# We are not compatible with openssl1.1 changes
# So we adopt Debian way, use libressl instead.
BuildRequires:  libressl-devel
%else
BuildRequires:  openssl-devel
%endif
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  libxslt-devel
BuildRequires:  libxslt-tools
BuildRequires:  postgresql-server-devel
BuildRequires:  update-desktop-files
# openSUSE before Leap 15
%if 0%{?suse_version} <= 1315 && 0%{?is_opensuse} > 0
BuildRequires:  wxWidgets
BuildRequires:  wxWidgets-wxcontainer-devel
%define _use_internal_dependency_generator 0
%define __find_requires %wx_requires
%define WX_VER 2.8
%endif
# Tumbleweed or Leap 15 and later
%if 0%{?suse_version} >= 1500 && 0%{?is_opensuse} > 0
# nostl mandatory otherwise you get errors at compile and runtime
# too much wxChar used
%define WX_VER 3.0
BuildRequires:  wxWidgets-3_0-nostl-devel
%endif
# SLE 15
%if 0%{?suse_version} >= 1500 && 0%{?is_opensuse} == 0
# nostl mandatory otherwise you get errors at compile and runtime
# too much wxChar used
%define WX_VER 3.0
BuildRequires:  wxWidgets-3_0-nostl-devel
%endif
Requires:       libpq5 >= 9.3
Recommends:     %{name}-lang = %{version}
Suggests:       postgresql-server
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#Documentation build, sles doesn't know python-Sphinx
%if 0%{?sle_version} > 0
#dummy
%else
BuildRequires:  python-Sphinx
%endif

%description
pgAdmin III is an administration and management tool for the PostgreSQL
database and derivative products such as EnterpriseDB, Mammoth PostgreSQL,
Pervasive Postgres, and SRA PowerGres. It includes a graphical administration
interface, an SQL query tool with graphical EXPLAIN, a procedural code editor,
an SQL/shell/batch scheduling agent, Slony-I management, and much more. It is
designed to answer the needs of most users, from writing simple SQL queries to
developing complex databases. The graphical interface supports all PostgreSQL
features and makes administration easy.

%lang_package

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
autoreconf -fiv

sed -i 's/\r$//' LICENSE TODO CHANGELOG # remove wrong EOL
sed -i 's/\r$//' docs/*/pgadmin3.css # remove wrong EOL

rm -f docs/en_US/pgadmin3.hhp.cached # zero-length

%build
autoreconf -fiv
export CXXFLAGS="%optflags -fno-delete-null-pointer-checks"
%configure --enable-databasedesigner --disable-static --with-wx-version=%{WX_VER}
make %{?_smp_mflags}

%install

make DESTDIR=%{buildroot} STRIP=/bin/true install
install -D -m0644 "%{SOURCE2}" "%{buildroot}%{_datadir}/pixmaps/%{name}.png"

# whatever that symlink is doing there...
rm "%{buildroot}%{_datadir}/pgadmin3/i18n/wxstd.mo"

# fix permissions
find "%{buildroot}%{_datadir}/pgadmin3/docs/" -type f -exec chmod 644 {} \;

# collect and mark localized files
L="$PWD/%{name}.lang"
pushd "%{buildroot}%{_datadir}/pgadmin3/i18n"
find . -type d -mindepth 1 -maxdepth 1 -name '*_*' | while read d; do
    d="${d#./}"
    echo "%lang(${d}) %{_datadir}/pgadmin3/i18n/${d}" >> "$L"
done
popd
#"%%{buildroot}%%{_datadir}/pgadmin3/i18n"
pushd "%{buildroot}%{_datadir}/pgadmin3/docs"
find . -type d -mindepth 1 -maxdepth 1 -name '*_*' | while read d; do
    d="${d#./}"
    echo "%doc %lang(${d}) %{_datadir}/pgadmin3/docs/${d}" >> "$L"
done
popd
#"%%{buildroot}%%{_datadir}/pgadmin3/docs"

%if 0%{?sles_version} == 10 || 0%{?sles_version} == 9
%suse_update_desktop_file %{name} System Database
%else
%suse_update_desktop_file -i %name System Database
%endif

%fdupes -s "%{buildroot}%{_datadir}/pgadmin3"

%if 0%{?sles_version} != 10 && 0%{?sles_version} != 9
%files
%defattr(-, root, root)
%else
%files -f %{name}.lang
%endif
%defattr(-, root, root)
%doc BUGS CHANGELOG LICENSE README TODO
%{_bindir}/pgadmin3
%dir %{_datadir}/pgadmin3
%doc %dir %{_datadir}/pgadmin3/docs
%dir %{_datadir}/pgadmin3/i18n
%{_datadir}/pgadmin3/i18n/pgadmin3.lng
%{_datadir}/pgadmin3/i18n/pg_settings.csv
%dir %{_datadir}/pgadmin3/branding
%dir %{_datadir}/pgadmin3/plugins.d
%config(noreplace) %{_datadir}/pgadmin3/branding/branding.ini
%config(noreplace) %{_datadir}/pgadmin3/plugins.d/plugins.ini
%config(noreplace) %{_datadir}/pgadmin3/settings.ini
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png

%if 0%{?sles_version} != 10 && 0%{?sles_version} != 9
%files lang -f %{name}.lang
%defattr(-, root, root)
%endif

%changelog
* Tue May 29 2018 mail@pcvolkmer.de
- Changed spec file to select dependencies for Leap 15.0
* Fri Mar 30 2018 ralf.habacker@freenet.de
- Added 0003-postgresql-8.3-support.patch to fix invalid
  sql statement on accessing postgresql 8.3 database
* Sat Nov 25 2017 bruno@ioda-net.ch
- Fix boo#1069822 Can't build with openssl 1.1
  (Coming soon as default in Tumbleweed 201711*)
  Adopt Debian way, by switching to libressl-devel.
* Fri Nov 24 2017 bruno@ioda-net.ch
- Added path 0002-basic-support-postgresql10.patch inspired by
  openscg work on their fork pgadmin III LTS.
  Connection to postgresql10 server is now possible.
* Wed Nov 22 2017 bruno@ioda-net.ch
- Fix upstream sources url
* Tue Apr 18 2017 bruno@ioda-net.ch
- Add 0001-Set-row-heights-based-on-pixels-rather-than-points.patch
  Fix control grid row on hidpi screen.
* Sun Jan 29 2017 bruno@ioda-net.ch
- Packaging :
  + spec-clean minimal
  + remove obsolete version sle and openSUSE
  + globalize \r removal in css files
  + use wxWidgets-3_0-nostl-devel to remove dependency of gst 0.10
    so use internal dependency generator on openSUSE > 1315
  + Add WX_VER variable to build correctly
  + Added patch wxWidget-limit-libs-used.patch to explicitely add
    the needed libs.
  + Try to handle differents WX versions between openSUSE and SLE
* Wed Jan 11 2017 bruno@ioda-net.ch
- Update to version 1.22.2
  * Include the Negator when reverse engineering SQL for operators
  * Fix the psql plugin command on OSX to work more reliably
  * Prevent a crash in some situtions where the database connection
  is lost and needs to be reset.
  * Fix display of elapsed query time for queries running longer than
  1 hour
- This is the final release of pgadmin3
* Fri Jul  1 2016 martin.liska@suse.com
- Add -fno-delete-null-pointer-checks to CXXFLAGS to workaround
  boo#986857.
* Sun Feb 28 2016 crrodriguez@opensuse.org
- Update to version 1.22.1
  * Don't barf when connecting to Greenplum or Greenplum· HAWQ
  * Fix selection of conversion functions in the CREATE CONVERSION dialogue.
  * Properly quote type names in the Type dialogue, and·ensure range
  information is displayed for existing types
  * Fix selection of cast functions in the Cast dialogue
* Sun Feb 28 2016 crrodriguez@opensuse.org
- remove obsolete suse_version checks
- fix debuginfo generation.
* Tue Jan 26 2016 termim@gmail.com
- update to 1.22.0
  * Resolved an issue related to check options selection in the view
    properties dialog with the check option.
  * Merged the libssh2 to the latest version.
  * Properly detect serial columns as such when identifiers have been
    truncated.
  * Fixes an issue related to the column inheritance information properly,
    when one (or, more) common columns are inherited from multiple tables.
  * Ensure the correct syntax used for moving the objects from one
    tablespace to another.
  * Ensure the correct line endings are used when copying from the SQL Pane
  * Toolbar icons, and menu items for Commit and Rollback actions.
  * Display the connection details for the current browser object in the
    status bar
  * Fixed an issue related to different menus enabling in the Query Tool on
    Ubunutu unity.
  * Reset the position (x, y) for dialog(s), and frame(s) to 0 (if found
    negative), while saving its position and size.
  * Fixes an issue identifying the return type to TABLE in some cases,
    using pg_get_function_result(..) for the same instead of format_type(..)
  * Honour PGPASSFILE environment variable for saving, retrieving the
    password instead of always works with pgpass.conf (on windows)/.pgpass
    (on non-windows)
  * Fix a segfault occurs while detecting transaction section requirement,
    when autocommit has been disabled.
  * Format execution time in a more readable manner
  * Improve sorting in Data editor
  * Allow to format the selecte SQL using external tools in Query Editor
  * Allow to set auto-commit mode to on/off in the query editor
  * Do not try unlock the mutex, which was not owned by the thread, while
    creating the popup menu
  * Set the focus on browser tree windows on startup
  * Make the arrow key navigation consistent across all platform on the
    object browser tree
  * Show indexes for the materialized views in Query pane
  * Add support for searching materialized views in the
* Fri Oct 16 2015 jweberhofer@weberhofer.at
- Do not recommend but only suggest to install postgresql-server.
* Wed Aug 12 2015 mpluskal@suse.com
- Add explicit dependencies on autoconf and libtool
* Wed Jan 28 2015 termim@gmail.com
- update to 1.20.0
  * Resolving the inconsistency of preservation of modified
    information of the columns, while adding/editing a table from
    the table dialog
  * Add missing nodes to graphical explain plan
  * Fix the Resource Groups dialog - separated the statements,
    which can not be ran in single transaction
  * Support for Slony-I 2.2+ with PostgreSQL 9.3+
  * Support smallserial columns in Edit Data Window
  * Restore the user specified size on the grid (which contains the
    result) in Query windows to fix an issue related to the column
    size is too narrow on subsequent Explain execution
  * Empty the Undo/Redo history everytime new file is opened
  * Added accelerator F8 for 'Execute to file' in the Query window
  * Beautify the query shown in the SQL pane for the functions
    having multiple arguments by adding new lines with small
    modification
  * Check for the columnlist for the UPDATE OF syntax on trigger
    also works with PPAS 9.5+
  * Proper saving of columns width in the server status window
  * CHECK OPTION is applicable to the views only, and not the
    materialized views
  * Prevent a crash during the update of the macro or favourite
    list
  * Allow quick injectection of favourites by name
  * Fix handling of saving macros after pasting a query in the box
  * Fix handling of char()[] columns in the Edit Grid
  * Support the new check_option parameter of views
  * Handle the 9.4 MOVE clause of ALTER TABLESPACE
  * Add a new action menu to refresh a materialized view
  * Support the new 9.4 columns in pg_stat_activity
  * Save search options for next time
  * Ensure Favourite queries are only saved when the OK button is
    pressed
  * Fix an issue refreshing functions in PPAS packages
  * Improve handling of lost connections
  * Allow searching for database objects by comment and definition
    content
  * Add support for Resource Groups in PPAS 9.4
  * Add Save and Exit shortcut keys to the edit grid
  * Enable backward search in SQL Box using Shift + F3
  * Allow more flexible selection/deselection of rows and columns
    in Edit Grid
  * Allow more options with the plain backup.
  * Use a much smarter auto-sizing algorithm for the columns in the
    Query Tool output grid.
  * Remember the last panel used on the Options dialogue, and
    display the default panel if a group node is selected on the
    tree
  * Allow parallel dump with -j starting with 9.3
- update to 1.18.2
  * Fix SQL for GRANT on a sequence. Report from liuyuanyuan.
  * Fix escape handling in pgpass files
  * GQB forgot the materialized views.
  * Don't set log_min_messages from the debugger
  * Fix a crash on OSX when run explain through shortcut in query
    editor, when mouse is over a existing shape, and popup, showing
    the step information, is on
  * Using the GetOid() function instead of GetLong() for Oid
    columns
  * Fix SQL comments for inherited columns.
  * Flush the changes in the settings as soon as new server is
    added
  * Don't include obsolete config settings from <= 8.3 in the
    config editor unless running on an appropriate server.
  * Ensure the Type dialogue detects name changes.
  * Ensure report titles don't overflow the page width
  * Ensure reports overflow the page width properly
  * Add missing "port" option for SSH tunnels.
  * Set 32bit PostgreSQL, EnterpriseDB PATH (in case - 64bit
    respective applications not found, and 32bit(s) are available)
    for 64bit pgAdmin III.
  * Improved the debugger to work better with PPAS <= 9.2
  * Fix the handling of the "Valid Until" date/time on the role
    dialogue on Mac.
* Thu Dec 12 2013 max@suse.com
- Remove broken and unneeded dependency on libecpg (bnc#854754).
* Sat Oct 19 2013 bruno@ioda-net.ch
- spec remove cleaning png2c (fixed in 1.18)
- update to 1.18.1
  http://www.pgadmin.org/development/changelog.php
  Date       Dev Ver     Change details
  - --------- --- ------  --------------
  2013-09-29 GL  1.18.1  Allow the dump of pg<something> schemas.
  2013-09-26 DP  1.18.1  Prevent a crash on Windows when dropping a column or a
  constraint on a table [Dhiraj Chawla]
  2013-09-26 DP  1.18.1  Ensure DDLScript will work with Slony 2.2+ which has a
  new SQL level API [Neel Patel]
  2013-09-26 DP  1.18.1  Fix ordering of object types in the display options and
  add Event Triggers which were missing [Dhiraj Chawla].
  2013-09-21 AV  1.18.1  Ensure the debugger can cope with functions that have an
  OUT parameter as the first.
  2013-09-19 DP  1.18.1  Fix the quoting of user mapping objects [Dinesh Kumar]
  2013-09-19 DP  1.18.1  Ensure that materialised views are available as targets
  for synonyms [Neel Patel]
  2013-09-19 DP  1.18.1  Fix the query used to find tables in a Slony
  replication set [Neel Patel]
  2013-09-11 DP  1.18.1  Prevent a crash if a user starts an external process
  such as a backup, and then immediately hits cancel
  [Neel Patel].
  2013-09-06 DP  1.18.1  Fix a memory leak in the Event Trigger code [Dinesh
  Kumar].
  2013-08-20 AV  1.18.0  Fix a layout bug in the graphical explain renderer that
  could render nodes on top of each other.
  2013-08-06 DP  1.18.0  Fix Slony's DDL Script support [Akshay Joshi].
  2013-07-26 DP  1.18.0  Add support for Event Triggers in 9.3+ [Dinesh Kumar].
  2013-07-22 DP  1.18.0  Avoid using a Help cache file that needs to be world
  writeable, and ensure sed is happy when post-processing
  helpfiles.
  2013-07-22 DP  1.18.0  Fix the help path on the import dialogue and improve the
  error handling [Akshay Joshi].
  2013-07-22 DP  1.18.0  Fix path the the Search Objects help doc [Dhiraj Chawla].
  2013-07-18 GL  1.18.0  Fix UTF-8 display for guru hints [Marek Cernocky].
  2013-07-08 DP  1.18.0  Prevent a crash when creating a stored procedure in
  PPAS [Dinesh Kumar].
  2013-06-19 GL  1.18.0  Disable the Favourites menu items if there is no
  favourites file path (per a comment from Michael Shapiro).
  2013-06-18 GL  1.18.0  Make No the default button on the Truncate confirmation
  dialog (per request from Humberto Cereser Ibanez).
  2013-06-18 DP  1.18.0  Support Materialized Views [Neel Patel].
  2013-06-07 DP  1.18.0  Avoid a possible crash on Linux when using the
  "Script" options of the Query Tool [aditsu].
  2013-05-26 DP  1.18.0  Fix comments on constraints [Thom Brown].
  2013-05-26 DP  1.18.0  Fix schema prefixes in cast definitions in the browser.
  2013-05-26 DP  1.18.0  Treat sequences as first class objects in the Grant
  Wizard. Support USAGE and remove obsolete RULE
  permissions [Dhiraj Chawla].
  2013-05-26 DP  1.18.0  Set the default backup type to "Custom".
  2013-05-21 DP  1.18.0  Improve the copy handling on the Edit Grid so that
  it works more consistently and predictably.
  2013-05-20 DP  1.18.0  Fix comments on columns.
  2013-05-20 DP  1.18.0  Remove the "Apply" buttons from the function, view
  package and external table dialogues. Their use is
  discouraged, and the code is fragile, complex and
  very buggy.
  2013-05-20 DP  1.18.0  Fix a crash that could occur if the browser fails to
  detect that an object has been changed by another
  session.
  2013-05-17 DP  1.18.0  Change the default SQL box font to a slightly smaller
  size on GTK based platforms.
  2013-05-17 DP  1.18.0  Don't prompt the user for a password if they're using
  a client certificate.
  2013-05-17 DP  1.18.0  Ensure global backups use the mintenance database to
  avoid access issue with postgres or template1.
  2013-05-17 DP  1.18.0  Fix SSL certificate authentication.
  2013-05-08 DP  1.18.0  Fix renaming and schema changes for stored procedures
  in PPAS [Dinesh Kumar].
  2013-05-02 DP  1.18.0  Add SSH tunnelling support to allow connections to be
  made to hosts via an SSH server [Akshay Joshi].
  2013-05-02 DP  1.18.0  Display the index validity in the properties list for
  indexes and index-based constraints [Gabrielle Roth].
  2013-04-29 DP  1.18.0  Add an option to include column headers when copying
  from the query tool results [Jasmin Dizdarevic].
  2013-04-29 DP  1.18.0  Allow the decimal mark displayed by the query tool to be
  configured as the thousands separator can [Jasmin
  Dizdarevic].
  2013-04-25 DP  1.18.0  Ensure the Query Tool's maximum column length setting
  is honoured.
  2013-04-22 DP  1.18.0  Handle default privileges to PUBLIC correctly. [Dhiraj
  Chawla].
  2013-03-24 GL  1.18.0  Add tab option in the Import dialog. Per a request from
  Jeff Janes.
  2013-03-17 GL  1.18.0  Add smallserial handling. Per a request from Matthew
  Syphus.
  2013-03-01 DP  1.18.0  Fix the editing of pg_hba.conf files [Dhiraj Chawla].
  2013-02-25 DP  1.18.0  Fix the display of extension owner names.
  2013-02-23 GL  1.18.0  Add a title to the backup and restore windows. Per
  request from Bastiaan Olij.
  2013-02-22 DP  1.18.0  Fix a bug that could cause a NOTICE to be displayed
  when rendering FTS Configurations in the tree.
  2013-02-07 DP  1.18.0  Don't try to display dependents or dependencies for
  pgAgent jobs, schedules or steps.
  2013-02-06 DP  1.18.0  Fix the handling of expiry times when modifying roles.
  2013-02-04 DP  1.18.0  Prevent foreign keys being recreated unnecessarily when
  modifying tables [Michael Banck]
  2013-01-24 DP  1.18.0  Prevent Cmd+S adding characters to the Query Tool when
  the Save button is disabled.
  2013-01-18 DP  1.18.0  Fix handling of Greenplum partitions [Lubomir Petrov]
  2013-01-06 GL  1.18.0  Add -V/--version CLI option.
  2013-01-06 GL  1.18.0  Add actions menu to the serverstatus tool.
  2013-01-06 GL  1.18.0  Fix the database SQL when reseting a configuration
  parameter. Per a report from Bartosz Dmytrak.
  2013-01-04 GL  1.18.0  Refresh the toolbar buttons when a list has been
  updated. Per a report from Evan Martin.
  2013-01-04 GL  1.18.0  Fix the "NO INHERIT" query. Report from Thomas Joseph.
  2012-12-24 GL  1.18.0  Display default privs. Report from Nathan Alden.
  2012-12-24 GL  1.18.0  Sort references by schema name and relation name in
  dlgForeignKey. Report from Michal Kozusznik.
  2012-12-24 GL  1.18.0  Fix the change of the superuser attribute. Report from
  Michal Kozusznik.
  2012-12-18 DP  1.18.0  Prevent a crash when using Cmd-A on a file loaded into
  the Query Tool when opened with Cmd-E on Mac.
  2012-12-07 DP  1.18.0  Fix the queries used to get object comments to allow
  for duplicate OIDs that may be present following use
  of pg_upgrade.
* Mon Jan 28 2013 bruno@ioda-net.ch
- fix bnc#800831
- update to 1.16.1
  http://www.pgadmin.org/development/changelog.php
    Date       Dev Ver     Change details
  - --------- --- ------  --------------
    2012-12-03 DP  1.16.1  Prevent a crash that could happen if further changes
  were made on a dialogue after using the Apply button.
  [Akshay Joshi]
    2012-11-29 GL  1.16.1  Save new comments on already existing columns when
  editing a table. Per a report from Jeff Janes.
    2012-11-29 GL  1.16.1  Fix the query editor behaviour when executing COPY TO
  stdout and COPY FROM stdin [Heikki Linnakangas]
    2012-11-28 AV  1.16.1  Date picker controls returns a full timestamp by
  default, which can cause inadvertent date changes
  on jobs and role validty dates. Ignore the time part.
    2012-11-26 MH  1.16.1  Fix query for database descriptions
    2012-11-15 DP  1.16.1  Avoid querying the catalogs for toast table settings
  for every table in the database. This gives a huge
  performance gain with large schemas.
    2012-11-08 DP  1.16.1  Prevent a crash when refreshing a node which has a
  child with an open dialogue [Dhiraj Chawla]
    2012-11-08 DP  1.16.1  Fix dropping/renaming of indexes [Akshay Joshi]
    2012-11-08 DP  1.16.1  Avoid updating the GQB model on every key press in
  the query tool [Dhiraj Chawla]
    2012-11-02 DP  1.16.1  Fix a crash that can occur when renaming objects.
  [Ashesh Vashi/Sachin Srivastava]
    2012-11-01 DP  1.16.1  Fix dropping of constraints [Akshay Joshi]
    2012-10-31 DP  1.16.1  Fix the "blocked by" column in the server status
  dialogue on 9.2 servers [Sachin Srivastava]
    2012-10-11 DP  1.16.1  Prevent a crash if the query tool is closed whilst a
  file is loading [Akshay Joshi]
    2012-10-09 AV  1.16.1  Fix setting of comments on PPAS procedures.
    2012-10-08 DP  1.16.1  Don't autosize the search results columns if no
  results are found [Akshay Joshi]
    2012-10-08 AV  1.16.1  Prevent a crash if opening a second config file in
  the editor.
    2012-10-08 DP  1.16.1  Prevent the SSL options combo box displaying
  duplicate options if the server dialogue is
  reopened [Akshay Joshi]
    2012-09-14 GL  1.16.1  Fix trigger query when connected to PostgreSQL 8.2 or
  lower, per a report from Jon Roberts.
    2012-09-12 GL  1.16.1  Fix message when executing an empty query, per Marc
  Mamin.
    2012-05-08 GL  1.16.0  Add privilege support on aggregates.
    2012-05-05 GL  1.16.0  Add inline function support on languages.
    2012-04-29 GL  1.16.0  Add support for range types.
    2012-04-28 GL  1.16.0  Add support for setting db/user config on dlgRole.
    2012-04-08 GL  1.16.0  Move references table textbox to the third tab in
  dlgForeignKey. Per request from Colin Beckingham.
    2012-04-05 GL  1.16.0  Support for the new two columns in 9.2 pg_stat_database
    2012-03-12 GL  1.16.0  Support for renaming constraints (9.2).
    2012-03-02 GL  1.16.0  Fix wxWidgets 2.9 compatibility with pgAdmin on Linux
  [Akshay Joshi].
    2012-02-23 GL  1.16.0  New import tool.
    2012-02-15 GL  1.16.0  Support for the LEAKPROOF option in functions.
    2012-02-13 GL  1.16.0  Support ANALYZE, CATEGORY, and PREFERED items for
  CREATE TYPE statement.
    2012-02-11 GL  1.16.0  Support CREATE TABLE LIKE.
    2012-02-09 GL  1.16.0  Support for the new TIMING option in EXPLAIN ANALYZE.
    2012-01-26 GL  1.16.0  Support for the new three columns in 9.2 pg_stat_database
    2012-01-22 GL  1.16.0  Use date_trunc to skip the microseconds part of all
  timestamp fields in frmStatus.
    2012-01-22 GL  1.16.0  Support new/changed pg_stat_activity fields.
    2012-01-08 GL  1.16.0  Allow renaming a domain.
    2012-01-07 GL  1.16.0  Add subitems to the schemas and catalogs in GQB.
  Request from Colin Beckingham.
    2012-01-05 GL  1.16.0  Support section options for pg_dump/pg_restore.
    2012-01-03 GL  1.16.0  Add security_barrier option handling for views.
    2011-12-19 DP  1.16.0  Add an "New Folder" button to the "Add Favourite" dialog
  in the query tool [Dhiraj Chawla]
    2011-12-12 GL  1.16.0  Support for the new sslcompression connection option.
    2011-12-11 GL  1.16.0  Add renaming of FDW and Server objects.
    2011-12-10 GL  1.16.0  Support for TRUNCATE permission
    2011-09-10 GL  1.16.0  Reverse engineering in the database designer.
  Patch from Luis Ochoa with some fixes by me.
    2011-09-04 GL  1.16.0  Highlight the other brace even if the current one is
  before the caret (request from Andreas).
    2011-08-24 DP  1.16.0  Add options to refresh objects automatically when
  clicked [Vinicius Santos]
    2011-08-15 GL  1.16.0  Redesign frmOptions.
    2011-08-11 GL  1.16.0  Prevents dropping connection, dropping or refreshing
  object when a properties dialog is open.
    2011-08-11 GL  1.16.0  Support for multimodels diagram in the database
  designer. Patch from Luis Ochoa with some fixes by me.
    2011-08-07 GL  1.16.0  Implement enable/disable save button, on text change.
  Patch from Vinicius Santos.
    2011-07-25 GL  1.16.0  Change doc build system.
    2011-07-25 GL  1.16.0  Support for security labels on global/shared objects
  (9.2 feature).
    2011-07-25 GL  1.16.0  Support for security labels on local objects (9.1
  feature).
    2011-07-25 GL  1.16.0  Support for non valid domains, and check constraints
  (9.2 feature).
    2011-07-25 GL  1.16.0  Add load/save support for the Database Designer. Patch
  from Luis Ochoa.
    2011-07-09 GL  1.16.0  Allow change of schema in the UI. Patch from Thom
  Brown.
    2011-07-05 GL  1.16.0  Add "Search Objects" dialog. Patch from Jasmin Dizdarevic.
    2011-07-03 GL  1.16.0  New maintenance action: CLUSTER. Patch from Thom Brown.
    2011-07-02 GL  1.16.0  Enable "Has OIDs" on 8.4+ even when the table is
  already created. Patch from Thom Brown.
    2011-06-27 GL  1.16.0  Add Database Designer. Patch from Luis Ochoa.
    2011-06-23 DP  1.16.0  Allow change of the fill factor. Patch from Thom Brown.
* Sun Jun 24 2012 pascal.bleser@opensuse.org
- update to 1.14.3:
  http://www.pgadmin.org/development/changelog.php
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Fri Sep 16 2011 klaussfreire@gmail.com
- update to upstream 1.14.0
  * see http://www.pgadmin.org/development/changelog.php
* Mon Apr 11 2011 saschpe@suse.de
- set license to 'PostgreSQL', fixes bnc#675943
* Mon Mar 28 2011 klaussfreire@gmail.com
- update to upstream git 2011-03-28
* Tue Mar  1 2011 mrueckert@suse.de
- use wx_requires on 11.4 and newer
* Thu Feb  3 2011 saschpe@gmx.de
- added dependency on wxWidgets for openSUSE-11.4 and greater
* Wed Oct 27 2010 termim@gmail.com
- update to 1.12.1:
  * see http://www.pgadmin.org/development/changelog.php
* Sun Aug  1 2010 pascal.bleser@opensuse.org
- update to 1.10.5:
  * see http://www.pgadmin.org/development/changelog.php
- splitted out I18N into -lang subpackage
* Mon Jun  7 2010 pascal.bleser@opensuse.org
- update to 1.10.3:
  * fix the "quiet log" query in the status server
  * call Stored Procedures in EnterpriseDB in an anonymous block to prevent errors with out/inout parameters.
  * fix an error when working with packages on EnterpriseDB in 'postgres' mode
  * prevent a crash if the user cancels a restore operation
  * fix the refresh of a dropped function
  * fix to only show Storage value if the value is different from the type's default value
  * fix uncalled attempt to "change" array data types in dlgColumn
  * fix a crash that could occur if viewing a table with no rows in the Edit Grid
  * fix a crash occuring when a function with a parameter with a default is selected
  * don't offer debugging options to non-superusers on Postgres Plus Advanced Server < 8.4 which doesn't have support for user debugging
  * fix the saving and reverse engineering of parameters for database, table, and function
  * specify the schema of the table/function to restore if pg_restore's release is 8.2 or later
  * fix the reverse engineering of a rule
  * fix the recent files, by notifying each frmQuery to update their recent files -- same support for macros and favourites
  * fix the canvas resizing with really big table
  * add the missing RULEs for VIEWs in SQL pane
  * add groups in the owner combobox
  * get back to the Properties tab when a user connects to a server
  * fix the reverse engineering of a table when its columns have Storage or Statistics value
  * correct reverse engineering of a function that RETURNS TABLE
  * display the tablespace in the reverse-engineered SQL of the database
  * make sure "Use Replication" is visible even with a big comment on an column
  * prevent a crash on the GQB when someone right click to delete a join rather than properly select it
  * make sure that Statistics tab doesn't show more databases than Properties tab
  * warn the user if a file couldn't be opened because it contains invalid characters
  * fix command line quoting for backup/restore
  * avoid a crash when debugging NULL procedures
* Fri Mar 12 2010 pascal.bleser@opensuse.org
- update to 1.10.2:
  * correctly save the position of a pgFrame
  * fix the reverse engineering of a function
  * fix the xmlTextWriterEndDocument check when saving a favorite
  * fix an SQL error when changing a parameter for a database, role/user and a function
  * fix the display of a type with a specific typmod
  * select the server choosen with the /s command-line argument.
  * fix the call to the Slony-I storenode function
  * fix display of the date/time chooser
- changes from 1.10.1:
  * replace Alt-F4 with Ctrl-Q and Ctrl-W
  * prevent a crash if the edit grid is closed whilst it is loading data
  * don't attempt to remove rows in the edit grid if the user presses the delete key when the delete button is disabled
  * only offer valid server encodings for new databases
  * fix an issue with the ordering of the mappings in a text search configuration
  * fix a potential crash bug in the object browser
  * reverse engineer empty (not NULL) ACLs correctly
  * fix Greenplum support for column oriented partitions
  * ensure function variables get reset if the function is modified
  * fix cluster creation for Slony 2.0
  * reverse engineer function defaults values correctly
  * fix a potential crash in the edit grid
  * fix domain creation/modification for domains in non-default schemas
  * reverse engineer language privileges correctly
  * get rid of "No SQL query was generated." message dialog when no tables are selected in the GQB
  * hints files should be encoded in UTF-8
  * include comments on procedures in the reverse engineered SQL
  * fix an SQL syntax error when viewing the dependencies of a sequence
  * better fix for schedule and step dialogs
  * fix the menu entry in frmQuery
  * fix the dlgFunction handling of preload libraries
  * fix schedule and step dialogs
  * fix macros writing
  * fix error thrown when examining a Slony 2.x cluster
* Wed Oct 14 2009 max@suse.de
- New version: 1.10.0
- Clean up spec file.
- bnc#546680:
  * Fix build in 11.2
  * Loosen dependency on PostgreSQL version
* Thu Dec 11 2008 crrodriguez@suse.de
- fix build in 11.1
* Mon Jun 16 2008 crrodriguez@suse.de
- do not require postgresql-server only Recommend it
* Mon Jun  2 2008 crrodriguez@suse.de
- use rpm opt flags
